# Copyright 2018 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import io
import os

import setuptools

name = 'google-cloud-automl'
description = 'Cloud AutoML API client library'
version = '0.2.0'
release_status = 'Development Status :: 3 - Alpha'
dependencies = [
    'google-api-core[grpc] >= 1.6.0, < 2.0.0dev',
    'enum34; python_version < "3.4"',
]

package_root = os.path.abspath(os.path.dirname(__file__))

readme_filename = os.path.join(package_root, 'README.rst')
with io.open(readme_filename, encoding='utf-8') as readme_file:
    readme = readme_file.read()

packages = [
    package for package in setuptools.find_packages()
    if package.startswith('google')
]

namespaces = ['google']
if 'google.cloud' in packages:
    namespaces.append('google.cloud')

setuptools.setup(
    name=name,
    version=version,
    description=description,
    long_description=readme,
    author='Google LLC',
    author_email='googleapis-packages@oogle.com',
    license='Apache 2.0',
    url='https://github.com/GoogleCloudPlatform/google-cloud-python',
    classifiers=[
        release_status,
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Operating System :: OS Independent',
        'Topic :: Internet',
    ],
    platforms='Posix; MacOS X; Windows',
    packages=packages,
    namespace_packages=namespaces,
    install_requires=dependencies,
    python_requires='>=2.7,!=3.0.*,!=3.1.*,!=3.2.*,!=3.3.*',
    include_package_data=True,
    zip_safe=False,
)



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/data_items.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from google.protobuf import duration_pb2 as google_dot_protobuf_dot_duration__pb2
from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/data_items.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/data_items.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto\x1a\x19google/protobuf/any.proto\x1a\x1egoogle/protobuf/duration.proto\x1a\x1cgoogle/protobuf/struct.proto"\x7f\n\x05Image\x12\x15\n\x0bimage_bytes\x18\x01 \x01(\x0cH\x00\x12@\n\x0cinput_config\x18\x06 \x01(\x0b\x32(.google.cloud.automl.v1beta1.InputConfigH\x00\x12\x15\n\rthumbnail_uri\x18\x04 \x01(\tB\x06\n\x04\x64\x61ta"F\n\x0bTextSnippet\x12\x0f\n\x07\x63ontent\x18\x01 \x01(\t\x12\x11\n\tmime_type\x18\x02 \x01(\t\x12\x13\n\x0b\x63ontent_uri\x18\x04 \x01(\t"R\n\x08\x44ocument\x12\x46\n\x0cinput_config\x18\x01 \x01(\x0b\x32\x30.google.cloud.automl.v1beta1.DocumentInputConfig"F\n\x03Row\x12\x17\n\x0f\x63olumn_spec_ids\x18\x02 \x03(\t\x12&\n\x06values\x18\x03 \x03(\x0b\x32\x16.google.protobuf.Value"\xfe\x01\n\x0e\x45xamplePayload\x12\x33\n\x05image\x18\x01 \x01(\x0b\x32".google.cloud.automl.v1beta1.ImageH\x00\x12@\n\x0ctext_snippet\x18\x02 \x01(\x0b\x32(.google.cloud.automl.v1beta1.TextSnippetH\x00\x12\x39\n\x08\x64ocument\x18\x04 \x01(\x0b\x32%.google.cloud.automl.v1beta1.DocumentH\x00\x12/\n\x03row\x18\x03 \x01(\x0b\x32 .google.cloud.automl.v1beta1.RowH\x00\x42\t\n\x07payloadB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_duration__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_struct__pb2.DESCRIPTOR,
    ],
)


_IMAGE = _descriptor.Descriptor(
    name="Image",
    full_name="google.cloud.automl.v1beta1.Image",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="image_bytes",
            full_name="google.cloud.automl.v1beta1.Image.image_bytes",
            index=0,
            number=1,
            type=12,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b(""),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.Image.input_config",
            index=1,
            number=6,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="thumbnail_uri",
            full_name="google.cloud.automl.v1beta1.Image.thumbnail_uri",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="data",
            full_name="google.cloud.automl.v1beta1.Image.data",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=246,
    serialized_end=373,
)


_TEXTSNIPPET = _descriptor.Descriptor(
    name="TextSnippet",
    full_name="google.cloud.automl.v1beta1.TextSnippet",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="content",
            full_name="google.cloud.automl.v1beta1.TextSnippet.content",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="mime_type",
            full_name="google.cloud.automl.v1beta1.TextSnippet.mime_type",
            index=1,
            number=2,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="content_uri",
            full_name="google.cloud.automl.v1beta1.TextSnippet.content_uri",
            index=2,
            number=4,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=375,
    serialized_end=445,
)


_DOCUMENT = _descriptor.Descriptor(
    name="Document",
    full_name="google.cloud.automl.v1beta1.Document",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="input_config",
            full_name="google.cloud.automl.v1beta1.Document.input_config",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=447,
    serialized_end=529,
)


_ROW = _descriptor.Descriptor(
    name="Row",
    full_name="google.cloud.automl.v1beta1.Row",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="column_spec_ids",
            full_name="google.cloud.automl.v1beta1.Row.column_spec_ids",
            index=0,
            number=2,
            type=9,
            cpp_type=9,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="values",
            full_name="google.cloud.automl.v1beta1.Row.values",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=531,
    serialized_end=601,
)


_EXAMPLEPAYLOAD = _descriptor.Descriptor(
    name="ExamplePayload",
    full_name="google.cloud.automl.v1beta1.ExamplePayload",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="image",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.image",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="text_snippet",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.text_snippet",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="document",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.document",
            index=2,
            number=4,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="row",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.row",
            index=3,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="payload",
            full_name="google.cloud.automl.v1beta1.ExamplePayload.payload",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=604,
    serialized_end=858,
)

_IMAGE.fields_by_name[
    "input_config"
].message_type = google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._INPUTCONFIG
_IMAGE.oneofs_by_name["data"].fields.append(_IMAGE.fields_by_name["image_bytes"])
_IMAGE.fields_by_name["image_bytes"].containing_oneof = _IMAGE.oneofs_by_name["data"]
_IMAGE.oneofs_by_name["data"].fields.append(_IMAGE.fields_by_name["input_config"])
_IMAGE.fields_by_name["input_config"].containing_oneof = _IMAGE.oneofs_by_name["data"]
_DOCUMENT.fields_by_name[
    "input_config"
].message_type = (
    google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2._DOCUMENTINPUTCONFIG
)
_ROW.fields_by_name["values"].message_type = google_dot_protobuf_dot_struct__pb2._VALUE
_EXAMPLEPAYLOAD.fields_by_name["image"].message_type = _IMAGE
_EXAMPLEPAYLOAD.fields_by_name["text_snippet"].message_type = _TEXTSNIPPET
_EXAMPLEPAYLOAD.fields_by_name["document"].message_type = _DOCUMENT
_EXAMPLEPAYLOAD.fields_by_name["row"].message_type = _ROW
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["image"]
)
_EXAMPLEPAYLOAD.fields_by_name[
    "image"
].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name["payload"]
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["text_snippet"]
)
_EXAMPLEPAYLOAD.fields_by_name[
    "text_snippet"
].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name["payload"]
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["document"]
)
_EXAMPLEPAYLOAD.fields_by_name[
    "document"
].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name["payload"]
_EXAMPLEPAYLOAD.oneofs_by_name["payload"].fields.append(
    _EXAMPLEPAYLOAD.fields_by_name["row"]
)
_EXAMPLEPAYLOAD.fields_by_name["row"].containing_oneof = _EXAMPLEPAYLOAD.oneofs_by_name[
    "payload"
]
DESCRIPTOR.message_types_by_name["Image"] = _IMAGE
DESCRIPTOR.message_types_by_name["TextSnippet"] = _TEXTSNIPPET
DESCRIPTOR.message_types_by_name["Document"] = _DOCUMENT
DESCRIPTOR.message_types_by_name["Row"] = _ROW
DESCRIPTOR.message_types_by_name["ExamplePayload"] = _EXAMPLEPAYLOAD
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Image = _reflection.GeneratedProtocolMessageType(
    "Image",
    (_message.Message,),
    dict(
        DESCRIPTOR=_IMAGE,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A representation of an image. Only images up to 30MB in size are
  supported.
  
  
  Attributes:
      data:
          Input only. The data representing the image. For Predict calls
          [image\_bytes][] must be set, as other options are not
          currently supported by prediction API. You can read the
          contents of an uploaded image by using the [content\_uri][]
          field.
      image_bytes:
          Image content represented as a stream of bytes. Note: As with
          all ``bytes`` fields, protobuffers use a pure binary
          representation, whereas JSON representations use base64.
      input_config:
          An input config specifying the content of the image.
      thumbnail_uri:
          Output only. HTTP URI to the thumbnail image.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Image)
    ),
)
_sym_db.RegisterMessage(Image)

TextSnippet = _reflection.GeneratedProtocolMessageType(
    "TextSnippet",
    (_message.Message,),
    dict(
        DESCRIPTOR=_TEXTSNIPPET,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A representation of a text snippet.
  
  
  Attributes:
      content:
          Required. The content of the text snippet as a string. Up to
          250000 characters long.
      mime_type:
          The format of the source text. Currently the only two allowed
          values are "text/html" and "text/plain". If left blank the
          format is automatically determined from the type of the
          uploaded content.
      content_uri:
          Output only. HTTP URI where you can download the content.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.TextSnippet)
    ),
)
_sym_db.RegisterMessage(TextSnippet)

Document = _reflection.GeneratedProtocolMessageType(
    "Document",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DOCUMENT,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A structured text document e.g. a PDF.
  
  
  Attributes:
      input_config:
          An input config specifying the content of the document.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Document)
    ),
)
_sym_db.RegisterMessage(Document)

Row = _reflection.GeneratedProtocolMessageType(
    "Row",
    (_message.Message,),
    dict(
        DESCRIPTOR=_ROW,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""A representation of a row in a relational table.
  
  
  Attributes:
      column_spec_ids:
          The resource IDs of the column specs describing the columns of
          the row. If set must contain, but possibly in a different
          order, all input feature  [column\_spec\_ids][google.cloud.aut
          oml.v1beta1.TablesModelMetadata.input\_feature\_column\_specs]
          of the Model this row is being passed to. Note: The below
          ``values`` field must match order of this field, if this field
          is set.
      values:
          Required. The values of the row cells, given in the same order
          as the column\_spec\_ids, or, if not set, then in the same
          order as input feature  [column\_specs][google.cloud.automl.v1
          beta1.TablesModelMetadata.input\_feature\_column\_specs] of
          the Model this row is being passed to.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.Row)
    ),
)
_sym_db.RegisterMessage(Row)

ExamplePayload = _reflection.GeneratedProtocolMessageType(
    "ExamplePayload",
    (_message.Message,),
    dict(
        DESCRIPTOR=_EXAMPLEPAYLOAD,
        __module__="google.cloud.automl_v1beta1.proto.data_items_pb2",
        __doc__="""Example data used for training or prediction.
  
  
  Attributes:
      payload:
          Required. Input only. The example data.
      image:
          Example image.
      text_snippet:
          Example text.
      document:
          Example document.
      row:
          Example relational table row.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.ExamplePayload)
    ),
)
_sym_db.RegisterMessage(ExamplePayload)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
#
# Copyright 2019 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     https://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
"""Wrappers for protocol buffer enum types."""

import enum


class ClassificationType(enum.IntEnum):
    """
    Type of the classification problem.

    Attributes:
      CLASSIFICATION_TYPE_UNSPECIFIED (int): Should not be used, an un-set enum has this value by default.
      MULTICLASS (int): At most one label is allowed per example.
      MULTILABEL (int): Multiple labels are allowed for one example.
    """

    CLASSIFICATION_TYPE_UNSPECIFIED = 0
    MULTICLASS = 1
    MULTILABEL = 2


class NullValue(enum.IntEnum):
    """
    ``NullValue`` is a singleton enumeration to represent the null value for
    the ``Value`` type union.

    The JSON representation for ``NullValue`` is JSON ``null``.

    Attributes:
      NULL_VALUE (int): Null value.
    """

    NULL_VALUE = 0


class TypeCode(enum.IntEnum):
    """
    ``TypeCode`` is used as a part of ``DataType``.

    Each legal value of a DataType can be encoded to or decoded from a JSON
    value, using the encodings listed below, and definitions of which can be
    found at

    https: //developers.google.com/protocol-buffers //
    /docs/reference/google.protobuf#value.

    Attributes:
      TYPE_CODE_UNSPECIFIED (int): Not specified. Should not be used.
      FLOAT64 (int): Encoded as ``number``, or the strings ``"NaN"``, ``"Infinity"``, or
      ``"-Infinity"``.
      TIMESTAMP (int): Must be between 0AD and 9999AD. Encoded as ``string`` according to
      ``time_format``, or, if that format is not set, then in RFC 3339
      ``date-time`` format, where ``time-offset`` = ``"Z"`` (e.g.
      1985-04-12T23:20:50.52Z).
      STRING (int): Encoded as ``string``.
      ARRAY (int): Encoded as ``list``, where the list elements are represented according
      to

      ``list_element_type``.
      STRUCT (int): Encoded as ``struct``, where field values are represented according to
      ``struct_type``.
      CATEGORY (int): Values of this type are not further understood by AutoML, e.g. AutoML is
      unable to tell the order of values (as it could with FLOAT64), or is
      unable to say if one value contains another (as it could with STRING).
      Encoded as ``string`` (bytes should be base64-encoded, as described in
      RFC 4648, section 4).
    """

    TYPE_CODE_UNSPECIFIED = 0
    FLOAT64 = 3
    TIMESTAMP = 4
    STRING = 6
    ARRAY = 8
    STRUCT = 9
    CATEGORY = 10


class Model(object):
    class DeploymentState(enum.IntEnum):
        """
        Deployment state of the model.

        Attributes:
          DEPLOYMENT_STATE_UNSPECIFIED (int): Should not be used, an un-set enum has this value by default.
          DEPLOYED (int): Model is deployed.
          UNDEPLOYED (int): Model is not deployed.
        """

        DEPLOYMENT_STATE_UNSPECIFIED = 0
        DEPLOYED = 1
        UNDEPLOYED = 2



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.cloud.automl_v1beta1.proto import (
    column_spec_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    dataset_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    model_evaluation_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    model_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    service_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    table_spec_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2,
)
from google.longrunning import (
    operations_pb2 as google_dot_longrunning_dot_operations__pb2,
)


class AutoMlStub(object):
    """AutoML Server API.

  The resource names are assigned by the server.
  The server never reuses names that it has created after the resources with
  those names are deleted.

  An ID of a resource is the last element of the item's resource name. For
  `projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`, then
  the id for the item is `{dataset_id}`.

  Currently the only supported `location_id` is "us-central1".

  On any input that is documented to expect a string parameter in
  snake_case or kebab-case, either of those cases is accepted.
  """

    def __init__(self, channel):
        """Constructor.

    Args:
      channel: A grpc.Channel.
    """
        self.CreateDataset = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/CreateDataset",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.CreateDatasetRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.Dataset.FromString,
        )
        self.GetDataset = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/GetDataset",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetDatasetRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.Dataset.FromString,
        )
        self.ListDatasets = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ListDatasets",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListDatasetsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListDatasetsResponse.FromString,
        )
        self.UpdateDataset = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/UpdateDataset",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UpdateDatasetRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.Dataset.FromString,
        )
        self.DeleteDataset = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/DeleteDataset",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.DeleteDatasetRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.ImportData = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ImportData",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ImportDataRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.ExportData = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ExportData",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ExportDataRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.GetAnnotationSpec = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/GetAnnotationSpec",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetAnnotationSpecRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.AnnotationSpec.FromString,
        )
        self.GetTableSpec = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/GetTableSpec",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetTableSpecRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2.TableSpec.FromString,
        )
        self.ListTableSpecs = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ListTableSpecs",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListTableSpecsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListTableSpecsResponse.FromString,
        )
        self.UpdateTableSpec = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/UpdateTableSpec",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UpdateTableSpecRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2.TableSpec.FromString,
        )
        self.GetColumnSpec = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/GetColumnSpec",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetColumnSpecRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.ColumnSpec.FromString,
        )
        self.ListColumnSpecs = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ListColumnSpecs",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListColumnSpecsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListColumnSpecsResponse.FromString,
        )
        self.UpdateColumnSpec = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/UpdateColumnSpec",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UpdateColumnSpecRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.ColumnSpec.FromString,
        )
        self.CreateModel = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/CreateModel",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.CreateModelRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.GetModel = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/GetModel",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetModelRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2.Model.FromString,
        )
        self.ListModels = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ListModels",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelsResponse.FromString,
        )
        self.DeleteModel = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/DeleteModel",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.DeleteModelRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.DeployModel = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/DeployModel",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.DeployModelRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.UndeployModel = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/UndeployModel",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UndeployModelRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.ExportModel = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ExportModel",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ExportModelRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.ExportEvaluatedExamples = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ExportEvaluatedExamples",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ExportEvaluatedExamplesRequest.SerializeToString,
            response_deserializer=google_dot_longrunning_dot_operations__pb2.Operation.FromString,
        )
        self.GetModelEvaluation = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/GetModelEvaluation",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetModelEvaluationRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2.ModelEvaluation.FromString,
        )
        self.ListModelEvaluations = channel.unary_unary(
            "/google.cloud.automl.v1beta1.AutoMl/ListModelEvaluations",
            request_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelEvaluationsRequest.SerializeToString,
            response_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelEvaluationsResponse.FromString,
        )


class AutoMlServicer(object):
    """AutoML Server API.

  The resource names are assigned by the server.
  The server never reuses names that it has created after the resources with
  those names are deleted.

  An ID of a resource is the last element of the item's resource name. For
  `projects/{project_id}/locations/{location_id}/datasets/{dataset_id}`, then
  the id for the item is `{dataset_id}`.

  Currently the only supported `location_id` is "us-central1".

  On any input that is documented to expect a string parameter in
  snake_case or kebab-case, either of those cases is accepted.
  """

    def CreateDataset(self, request, context):
        """Creates a dataset.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetDataset(self, request, context):
        """Gets a dataset.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListDatasets(self, request, context):
        """Lists datasets in a project.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateDataset(self, request, context):
        """Updates a dataset.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteDataset(self, request, context):
        """Deletes a dataset and all of its contents.
    Returns empty response in the
    [response][google.longrunning.Operation.response] field when it completes,
    and `delete_details` in the
    [metadata][google.longrunning.Operation.metadata] field.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ImportData(self, request, context):
        """Imports data into a dataset. For Tables this method can only be called on an empty Dataset.

    For Tables:
    *   A
    [schema_inference_version][google.cloud.automl.v1beta1.InputConfig.params]
    parameter must be explicitly set.
    Returns an empty response in the
    [response][google.longrunning.Operation.response] field when it completes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportData(self, request, context):
        """Exports dataset's data to the provided output location.
    Returns an empty response in the
    [response][google.longrunning.Operation.response] field when it completes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetAnnotationSpec(self, request, context):
        """Gets an annotation spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetTableSpec(self, request, context):
        """Gets a table spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListTableSpecs(self, request, context):
        """Lists table specs in a dataset.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateTableSpec(self, request, context):
        """Updates a table spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetColumnSpec(self, request, context):
        """Gets a column spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListColumnSpecs(self, request, context):
        """Lists column specs in a table spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UpdateColumnSpec(self, request, context):
        """Updates a column spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def CreateModel(self, request, context):
        """Creates a model.
    Returns a Model in the [response][google.longrunning.Operation.response]
    field when it completes.
    When you create a model, several model evaluations are created for it:
    a global evaluation, and one evaluation for each annotation spec.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetModel(self, request, context):
        """Gets a model.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListModels(self, request, context):
        """Lists models.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeleteModel(self, request, context):
        """Deletes a model.
    Returns `google.protobuf.Empty` in the
    [response][google.longrunning.Operation.response] field when it completes,
    and `delete_details` in the
    [metadata][google.longrunning.Operation.metadata] field.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def DeployModel(self, request, context):
        """Deploys a model. If a model is already deployed, deploying it with the
    same parameters has no effect. Deploying with different parametrs
    (as e.g. changing

    [node_number][google.cloud.automl.v1beta1.ImageObjectDetectionModelDeploymentMetadata.node_number]
    ) will update the deployment without pausing the model's availability.

    Only applicable for Text Classification, Image Object Detection and Tables;
    all other domains manage deployment automatically.

    Returns an empty response in the
    [response][google.longrunning.Operation.response] field when it completes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def UndeployModel(self, request, context):
        """Undeploys a model. If the model is not deployed this method has no effect.

    Only applicable for Text Classification, Image Object Detection and Tables;
    all other domains manage deployment automatically.

    Returns an empty response in the
    [response][google.longrunning.Operation.response] field when it completes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportModel(self, request, context):
        """Exports a trained, "export-able", model to a user specified Google Cloud
    Storage location. A model is considered export-able if and only if it has
    an export format defined for it in

    [ModelExportOutputConfig][google.cloud.automl.v1beta1.ModelExportOutputConfig].

    Returns an empty response in the
    [response][google.longrunning.Operation.response] field when it completes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ExportEvaluatedExamples(self, request, context):
        """Exports examples on which the model was evaluated (i.e. which were in the
    TEST set of the dataset the model was created from), together with their
    ground truth annotations and the annotations created (predicted) by the
    model.
    The examples, ground truth and predictions are exported in the state
    they were at the moment the model was evaluated.

    This export is available only for 30 days since the model evaluation is
    created.

    Currently only available for Tables.

    Returns an empty response in the
    [response][google.longrunning.Operation.response] field when it completes.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def GetModelEvaluation(self, request, context):
        """Gets a model evaluation.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")

    def ListModelEvaluations(self, request, context):
        """Lists model evaluations.
    """
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details("Method not implemented!")
        raise NotImplementedError("Method not implemented!")


def add_AutoMlServicer_to_server(servicer, server):
    rpc_method_handlers = {
        "CreateDataset": grpc.unary_unary_rpc_method_handler(
            servicer.CreateDataset,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.CreateDatasetRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.Dataset.SerializeToString,
        ),
        "GetDataset": grpc.unary_unary_rpc_method_handler(
            servicer.GetDataset,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetDatasetRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.Dataset.SerializeToString,
        ),
        "ListDatasets": grpc.unary_unary_rpc_method_handler(
            servicer.ListDatasets,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListDatasetsRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListDatasetsResponse.SerializeToString,
        ),
        "UpdateDataset": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateDataset,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UpdateDatasetRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.Dataset.SerializeToString,
        ),
        "DeleteDataset": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteDataset,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.DeleteDatasetRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "ImportData": grpc.unary_unary_rpc_method_handler(
            servicer.ImportData,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ImportDataRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "ExportData": grpc.unary_unary_rpc_method_handler(
            servicer.ExportData,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ExportDataRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "GetAnnotationSpec": grpc.unary_unary_rpc_method_handler(
            servicer.GetAnnotationSpec,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetAnnotationSpecRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_dataset__pb2.AnnotationSpec.SerializeToString,
        ),
        "GetTableSpec": grpc.unary_unary_rpc_method_handler(
            servicer.GetTableSpec,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetTableSpecRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2.TableSpec.SerializeToString,
        ),
        "ListTableSpecs": grpc.unary_unary_rpc_method_handler(
            servicer.ListTableSpecs,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListTableSpecsRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListTableSpecsResponse.SerializeToString,
        ),
        "UpdateTableSpec": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateTableSpec,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UpdateTableSpecRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_table__spec__pb2.TableSpec.SerializeToString,
        ),
        "GetColumnSpec": grpc.unary_unary_rpc_method_handler(
            servicer.GetColumnSpec,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetColumnSpecRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.ColumnSpec.SerializeToString,
        ),
        "ListColumnSpecs": grpc.unary_unary_rpc_method_handler(
            servicer.ListColumnSpecs,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListColumnSpecsRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListColumnSpecsResponse.SerializeToString,
        ),
        "UpdateColumnSpec": grpc.unary_unary_rpc_method_handler(
            servicer.UpdateColumnSpec,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UpdateColumnSpecRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_column__spec__pb2.ColumnSpec.SerializeToString,
        ),
        "CreateModel": grpc.unary_unary_rpc_method_handler(
            servicer.CreateModel,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.CreateModelRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "GetModel": grpc.unary_unary_rpc_method_handler(
            servicer.GetModel,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetModelRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__pb2.Model.SerializeToString,
        ),
        "ListModels": grpc.unary_unary_rpc_method_handler(
            servicer.ListModels,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelsRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelsResponse.SerializeToString,
        ),
        "DeleteModel": grpc.unary_unary_rpc_method_handler(
            servicer.DeleteModel,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.DeleteModelRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "DeployModel": grpc.unary_unary_rpc_method_handler(
            servicer.DeployModel,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.DeployModelRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "UndeployModel": grpc.unary_unary_rpc_method_handler(
            servicer.UndeployModel,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.UndeployModelRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "ExportModel": grpc.unary_unary_rpc_method_handler(
            servicer.ExportModel,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ExportModelRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "ExportEvaluatedExamples": grpc.unary_unary_rpc_method_handler(
            servicer.ExportEvaluatedExamples,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ExportEvaluatedExamplesRequest.FromString,
            response_serializer=google_dot_longrunning_dot_operations__pb2.Operation.SerializeToString,
        ),
        "GetModelEvaluation": grpc.unary_unary_rpc_method_handler(
            servicer.GetModelEvaluation,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.GetModelEvaluationRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_model__evaluation__pb2.ModelEvaluation.SerializeToString,
        ),
        "ListModelEvaluations": grpc.unary_unary_rpc_method_handler(
            servicer.ListModelEvaluations,
            request_deserializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelEvaluationsRequest.FromString,
            response_serializer=google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_service__pb2.ListModelEvaluationsResponse.SerializeToString,
        ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
        "google.cloud.automl.v1beta1.AutoMl", rpc_method_handlers
    )
    server.add_generic_rpc_handlers((generic_handler,))



# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/cloud/automl_v1beta1/proto/data_types.proto

import sys

_b = sys.version_info[0] < 3 and (lambda x: x) or (lambda x: x.encode("latin1"))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database

# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.cloud.automl_v1beta1.proto import (
    io_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2,
)
from google.cloud.automl_v1beta1.proto import (
    text_extraction_pb2 as google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__extraction__pb2,
)
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
    name="google/cloud/automl_v1beta1/proto/data_types.proto",
    package="google.cloud.automl.v1beta1",
    syntax="proto3",
    serialized_options=_b(
        "\n\037com.google.cloud.automl.v1beta1P\001ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\312\002\033Google\\Cloud\\AutoMl\\V1beta1"
    ),
    serialized_pb=_b(
        '\n2google/cloud/automl_v1beta1/proto/data_types.proto\x12\x1bgoogle.cloud.automl.v1beta1\x1a\x1cgoogle/api/annotations.proto\x1a*google/cloud/automl_v1beta1/proto/io.proto\x1a\x37google/cloud/automl_v1beta1/proto/text_extraction.proto\x1a\x19google/protobuf/any.proto"\xfc\x01\n\x08\x44\x61taType\x12\x42\n\x11list_element_type\x18\x02 \x01(\x0b\x32%.google.cloud.automl.v1beta1.DataTypeH\x00\x12>\n\x0bstruct_type\x18\x03 \x01(\x0b\x32\'.google.cloud.automl.v1beta1.StructTypeH\x00\x12\x15\n\x0btime_format\x18\x05 \x01(\tH\x00\x12\x38\n\ttype_code\x18\x01 \x01(\x0e\x32%.google.cloud.automl.v1beta1.TypeCode\x12\x10\n\x08nullable\x18\x04 \x01(\x08\x42\t\n\x07\x64\x65tails"\xa7\x01\n\nStructType\x12\x43\n\x06\x66ields\x18\x01 \x03(\x0b\x32\x33.google.cloud.automl.v1beta1.StructType.FieldsEntry\x1aT\n\x0b\x46ieldsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\x34\n\x05value\x18\x02 \x01(\x0b\x32%.google.cloud.automl.v1beta1.DataType:\x02\x38\x01*r\n\x08TypeCode\x12\x19\n\x15TYPE_CODE_UNSPECIFIED\x10\x00\x12\x0b\n\x07\x46LOAT64\x10\x03\x12\r\n\tTIMESTAMP\x10\x04\x12\n\n\x06STRING\x10\x06\x12\t\n\x05\x41RRAY\x10\x08\x12\n\n\x06STRUCT\x10\t\x12\x0c\n\x08\x43\x41TEGORY\x10\nB\x84\x01\n\x1f\x63om.google.cloud.automl.v1beta1P\x01ZAgoogle.golang.org/genproto/googleapis/cloud/automl/v1beta1;automl\xca\x02\x1bGoogle\\Cloud\\AutoMl\\V1beta1b\x06proto3'
    ),
    dependencies=[
        google_dot_api_dot_annotations__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_io__pb2.DESCRIPTOR,
        google_dot_cloud_dot_automl__v1beta1_dot_proto_dot_text__extraction__pb2.DESCRIPTOR,
        google_dot_protobuf_dot_any__pb2.DESCRIPTOR,
    ],
)

_TYPECODE = _descriptor.EnumDescriptor(
    name="TypeCode",
    full_name="google.cloud.automl.v1beta1.TypeCode",
    filename=None,
    file=DESCRIPTOR,
    values=[
        _descriptor.EnumValueDescriptor(
            name="TYPE_CODE_UNSPECIFIED",
            index=0,
            number=0,
            serialized_options=None,
            type=None,
        ),
        _descriptor.EnumValueDescriptor(
            name="FLOAT64", index=1, number=3, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="TIMESTAMP", index=2, number=4, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="STRING", index=3, number=6, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="ARRAY", index=4, number=8, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="STRUCT", index=5, number=9, serialized_options=None, type=None
        ),
        _descriptor.EnumValueDescriptor(
            name="CATEGORY", index=6, number=10, serialized_options=None, type=None
        ),
    ],
    containing_type=None,
    serialized_options=None,
    serialized_start=666,
    serialized_end=780,
)
_sym_db.RegisterEnumDescriptor(_TYPECODE)

TypeCode = enum_type_wrapper.EnumTypeWrapper(_TYPECODE)
TYPE_CODE_UNSPECIFIED = 0
FLOAT64 = 3
TIMESTAMP = 4
STRING = 6
ARRAY = 8
STRUCT = 9
CATEGORY = 10


_DATATYPE = _descriptor.Descriptor(
    name="DataType",
    full_name="google.cloud.automl.v1beta1.DataType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="list_element_type",
            full_name="google.cloud.automl.v1beta1.DataType.list_element_type",
            index=0,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="struct_type",
            full_name="google.cloud.automl.v1beta1.DataType.struct_type",
            index=1,
            number=3,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="time_format",
            full_name="google.cloud.automl.v1beta1.DataType.time_format",
            index=2,
            number=5,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="type_code",
            full_name="google.cloud.automl.v1beta1.DataType.type_code",
            index=3,
            number=1,
            type=14,
            cpp_type=8,
            label=1,
            has_default_value=False,
            default_value=0,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="nullable",
            full_name="google.cloud.automl.v1beta1.DataType.nullable",
            index=4,
            number=4,
            type=8,
            cpp_type=7,
            label=1,
            has_default_value=False,
            default_value=False,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[
        _descriptor.OneofDescriptor(
            name="details",
            full_name="google.cloud.automl.v1beta1.DataType.details",
            index=0,
            containing_type=None,
            fields=[],
        )
    ],
    serialized_start=242,
    serialized_end=494,
)


_STRUCTTYPE_FIELDSENTRY = _descriptor.Descriptor(
    name="FieldsEntry",
    full_name="google.cloud.automl.v1beta1.StructType.FieldsEntry",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="key",
            full_name="google.cloud.automl.v1beta1.StructType.FieldsEntry.key",
            index=0,
            number=1,
            type=9,
            cpp_type=9,
            label=1,
            has_default_value=False,
            default_value=_b("").decode("utf-8"),
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
        _descriptor.FieldDescriptor(
            name="value",
            full_name="google.cloud.automl.v1beta1.StructType.FieldsEntry.value",
            index=1,
            number=2,
            type=11,
            cpp_type=10,
            label=1,
            has_default_value=False,
            default_value=None,
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        ),
    ],
    extensions=[],
    nested_types=[],
    enum_types=[],
    serialized_options=_b("8\001"),
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=580,
    serialized_end=664,
)

_STRUCTTYPE = _descriptor.Descriptor(
    name="StructType",
    full_name="google.cloud.automl.v1beta1.StructType",
    filename=None,
    file=DESCRIPTOR,
    containing_type=None,
    fields=[
        _descriptor.FieldDescriptor(
            name="fields",
            full_name="google.cloud.automl.v1beta1.StructType.fields",
            index=0,
            number=1,
            type=11,
            cpp_type=10,
            label=3,
            has_default_value=False,
            default_value=[],
            message_type=None,
            enum_type=None,
            containing_type=None,
            is_extension=False,
            extension_scope=None,
            serialized_options=None,
            file=DESCRIPTOR,
        )
    ],
    extensions=[],
    nested_types=[_STRUCTTYPE_FIELDSENTRY],
    enum_types=[],
    serialized_options=None,
    is_extendable=False,
    syntax="proto3",
    extension_ranges=[],
    oneofs=[],
    serialized_start=497,
    serialized_end=664,
)

_DATATYPE.fields_by_name["list_element_type"].message_type = _DATATYPE
_DATATYPE.fields_by_name["struct_type"].message_type = _STRUCTTYPE
_DATATYPE.fields_by_name["type_code"].enum_type = _TYPECODE
_DATATYPE.oneofs_by_name["details"].fields.append(
    _DATATYPE.fields_by_name["list_element_type"]
)
_DATATYPE.fields_by_name[
    "list_element_type"
].containing_oneof = _DATATYPE.oneofs_by_name["details"]
_DATATYPE.oneofs_by_name["details"].fields.append(
    _DATATYPE.fields_by_name["struct_type"]
)
_DATATYPE.fields_by_name["struct_type"].containing_oneof = _DATATYPE.oneofs_by_name[
    "details"
]
_DATATYPE.oneofs_by_name["details"].fields.append(
    _DATATYPE.fields_by_name["time_format"]
)
_DATATYPE.fields_by_name["time_format"].containing_oneof = _DATATYPE.oneofs_by_name[
    "details"
]
_STRUCTTYPE_FIELDSENTRY.fields_by_name["value"].message_type = _DATATYPE
_STRUCTTYPE_FIELDSENTRY.containing_type = _STRUCTTYPE
_STRUCTTYPE.fields_by_name["fields"].message_type = _STRUCTTYPE_FIELDSENTRY
DESCRIPTOR.message_types_by_name["DataType"] = _DATATYPE
DESCRIPTOR.message_types_by_name["StructType"] = _STRUCTTYPE
DESCRIPTOR.enum_types_by_name["TypeCode"] = _TYPECODE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DataType = _reflection.GeneratedProtocolMessageType(
    "DataType",
    (_message.Message,),
    dict(
        DESCRIPTOR=_DATATYPE,
        __module__="google.cloud.automl_v1beta1.proto.data_types_pb2",
        __doc__="""Indicated the type of data that can be stored in a structured data
  entity (e.g. a table).
  
  
  Attributes:
      details:
          Details of DataType-s that need additional specification.
      list_element_type:
          If
          [type\_code][google.cloud.automl.v1beta1.DataType.type\_code]
          == [ARRAY][google.cloud.automl.v1beta1.TypeCode.ARRAY], then
          ``list_element_type`` is the type of the elements.
      struct_type:
          If
          [type\_code][google.cloud.automl.v1beta1.DataType.type\_code]
          == [STRUCT][google.cloud.automl.v1beta1.TypeCode.STRUCT], then
          ``struct_type`` provides type information for the struct's
          fields.
      time_format:
          If
          [type\_code][google.cloud.automl.v1beta1.DataType.type\_code]
          == [TIMESTAMP][google.cloud.automl.v1beta1.TypeCode.TIMESTAMP]
          then ``time_format`` provides the format in which that time
          field is expressed. The time\_format must either be one of: \*
          ``UNIX_SECONDS`` \* ``UNIX_MILLISECONDS`` \*
          ``UNIX_MICROSECONDS`` \* ``UNIX_NANOSECONDS`` (for
          respectively number of seconds, milliseconds, microseconds and
          nanoseconds since start of the Unix epoch); or be written in
          ``strftime`` syntax. If time\_format is not set, then the
          default format as described on the type\_code is used.
      type_code:
          Required. The [TypeCode][google.cloud.automl.v1beta1.TypeCode]
          for this type.
      nullable:
          If true, this DataType can also be ``null``.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.DataType)
    ),
)
_sym_db.RegisterMessage(DataType)

StructType = _reflection.GeneratedProtocolMessageType(
    "StructType",
    (_message.Message,),
    dict(
        FieldsEntry=_reflection.GeneratedProtocolMessageType(
            "FieldsEntry",
            (_message.Message,),
            dict(
                DESCRIPTOR=_STRUCTTYPE_FIELDSENTRY,
                __module__="google.cloud.automl_v1beta1.proto.data_types_pb2"
                # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.StructType.FieldsEntry)
            ),
        ),
        DESCRIPTOR=_STRUCTTYPE,
        __module__="google.cloud.automl_v1beta1.proto.data_types_pb2",
        __doc__="""``StructType`` defines the DataType-s of a
  [STRUCT][google.cloud.automl.v1beta1.TypeCode.STRUCT] type.
  
  
  Attributes:
      fields:
          Unordered map of struct field names to their data types.
          Fields cannot be added or removed via Update. Their names and
          data types are still mutable.
  """,
        # @@protoc_insertion_point(class_scope:google.cloud.automl.v1beta1.StructType)
    ),
)
_sym_db.RegisterMessage(StructType)
_sym_db.RegisterMessage(StructType.FieldsEntry)


DESCRIPTOR._options = None
_STRUCTTYPE_FIELDSENTRY._options = None
# @@protoc_insertion_point(module_scope)
